pynrc.maths.image\_manip
========================

.. automodule:: pynrc.maths.image_manip

   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
      :toctree:
   
      align_LSQ
      align_leastsq
      crop_image
      crop_observation
      fix_nans_with_med
      optimal_difference
      scale_ref_image
      shift_subtract
   
   

   
   
   

   
   
   



